Crate midenc_session

source ·

Re-exports

Modules

Structs

  • This enum represents the types of raw inputs provided to the compiler
  • A library requested by the user to be linked against during compilation
  • This struct contains all of the configuration options for the compiler
  • This struct provides access to all of the metadata and configuration needed during a single compilation session.
  • This struct contains various statistics about a compilation session

Enums

  • ColorChoice represents the color preferences of an end user.
  • This enum describes what type of debugging information to emit in compiled programs
  • This represents the file types recognized by the compiler
  • An error that occurs when detecting the file type of an input
  • The types of libraries that can be linked against during compilation
  • This enum describes the degree to which compiled programs will be optimized
  • The type of output to produce for a given OutputType, when multiple options are available
  • This enum represents the type of outputs the compiler can produce
  • This type describes an output type with optional path specification
  • The type of project being compiled
  • This enum describes the different target environments targetable by the compiler
  • This enum represents the type of messages produced by the compiler during execution
  • This enum represents the behavior of the compiler with regard to warnings

Constants

Traits