ComponentStartedInfo

Trait ComponentStartedInfo 

pub trait ComponentStartedInfo<T, S>{
    // Required methods
    fn get_receiver(&self) -> Option<Receiver<T>>;
    fn start_time(&self) -> BootInstant;
}
Trait for the providers of asynchronous receivers where the diagnostics data is sent. Used for simplying testing.

Required Methods

fn get_receiver(&self) -> Option<Receiver<T>>

Fetches a oneshot receiver that will eventually resolve to the diagnostics of a component if the runner provides them.

fn start_time(&self) -> BootInstant

Returns the reported start time.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ComponentStartedInfo<ComponentDiagnostics, Task> for RuntimeInfo

Implementors