pub trait ComponentStartedInfo<T, S>where
T: RuntimeStatsContainer<S>,
S: RuntimeStatsSource,{
// Required methods
fn get_receiver(&self) -> Option<Receiver<T>>;
fn start_time(&self) -> BootInstant;
}Expand description
Trait for the providers of asynchronous receivers where the diagnostics data is sent. Used for simplying testing.
Required Methods
Sourcefn get_receiver(&self) -> Option<Receiver<T>>
fn get_receiver(&self) -> Option<Receiver<T>>
Fetches a oneshot receiver that will eventually resolve to the diagnostics of a component if the runner provides them.
Sourcefn start_time(&self) -> BootInstant
fn start_time(&self) -> BootInstant
Returns the reported start time.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".